**Example 1: 删除集成任务**

删除集成任务

Input: 

```
tccli wedata DeleteIntegrationTask --cli-unfold-argument  \
    --ProjectId xx \
    --TaskId xx
```

Output: 
```
{
    "Response": {
        "RequestId": "xx",
        "Data": true
    }
}
```

